@@ -34,13 +34,37 @@ class MetaSerialiser(type):
 class Serialiser(object):
     __metaclass__ = MetaSerialiser
 
-    def object_deflate(self, obj, **kwargs):
-        data = {}
+    def __init__(self):
+        '''
+        Since the list of methods to call to deflate/inflate an object 
+        don't change, we might as well construct the lists once right here.
+        '''
+        # Build list of deflate and inflate methods
+        self._field_deflaters = []
+        self._custom_deflaters = []
+        self._field_inflaters = []
+        self._custom_inflaters = []
+
         for name, field in self._fields.items():
-            field.deflate(name, obj=obj, data=data, **kwargs)
+            self._field_deflaters.append((name, field.deflate))
             method = getattr(self, 'deflate_%s' % name, None)
             if method is not None:
-                data[name] = method(obj=obj, data=data, **kwargs)
+                self._custom_deflaters.append((name, method))
+
+            if field.readonly:
+                continue
+            method = getattr(self, 'inflate_%s' % name, None)
+            if method:
+                self._custom_inflaters.append((name, method))
+            else:
+                self._field_inflaters.append((name, field.inflate))
+
+    def object_deflate(self, obj, **kwargs):
+        data = {}
+        for name, method in self._field_deflaters:
+            method(name, obj=obj, data=data, **kwargs)
+        for name, method in self._custom_deflaters:
+            data[name] = method(obj=obj, data=data, **kwargs)
         return data
 
     def list_deflate(self, obj_list, **kwargs):
@@ -51,14 +75,10 @@ class Serialiser(object):
 
     def object_inflate(self, data, instance=None, **kwargs):
         obj = {}
-        for name, field in self._fields.items():
-            if field.readonly:
-                continue
-            method = getattr(self, 'inflate_%s' % name, None)
-            if method is not None:
-                obj[name] = method(data=data, obj=obj, instance=instance, **kwargs)
-            else:
-                field.inflate(name, data, obj, **kwargs)
+        for name, method in self._field_inflaters:
+            method(name, data=data, obj=obj, instance=instance, **kwargs)
+        for name, method in self._custom_inflaters:
+            obj[name] = method(data=data, obj=obj, instance=instance, **kwargs)
         return self.restore_object(obj, instance=instance, **kwargs)
 
     def list_inflate(self, data_list, **kwargs):
